
const templateBusiness = require('./business');
const logger = require('../utils/logger');


const updateAndMapWidget = async (req, res, next) => {
  try {
    const { page, widgetId, templateId } = req.params;
    const { position, startTime, endTime } = req.body;
    console.log(templateId)
    // Check for missing required fields and return 400 (Bad Request) if any are missing
    if (!page || !widgetId || !position || !startTime || !endTime || !templateId) {
      // Log the bad request
     
      logger.error(`Bad Request | Missing fields: ${JSON.stringify({ page, widgetId, position, startTime, endTime, templateId })}`);
      return res.status(400).json({ error: 'Missing required fields' });
    }

    logger.info(`Entering | updateAndMapWidget Controller | ${widgetId} for page ${page}`);
    const response = await templateBusiness.updateAndMapWidget(page, widgetId, position, startTime, endTime, templateId);

    return res.status(response.status).json({ data: response });
  } catch (error) {
    logger.error(`Error in updateAndMapWidget Controller: ${error.message}`);
    next(error); // Pass the error to the error handling middleware
  }
};


const createTemplate = async (req, res, next) => {
  try {
    const { name, desc, platform, widgets, hashId } = req.body;

    // Simple validation for required fields
    if (!name || !platform || !widgets || widgets.length === 0) {
      logger.error('Bad request: Missing required fields');
      return res.status(400).json({ message: 'Bad request: Missing required fields' });
    }

    // Log the incoming request
    logger.info(`Creating template: name=${name}, platform=${platform}`);

    const response = await templateBusiness.createTemplate(name, desc, platform, widgets, hashId);
    return res.status(response.status).json({ data: response });
  } catch (error) {
    logger.error(`Error creating template: ${error.message}`, { error });
    next(error); // Pass the error to an error handler middleware
  }
};


const getParticularTemplate = async (req, res) => {
  try {
    const { page } = req.params;
    const { platform } = req.query;

    // Basic validation
    if (!page || !platform) {
      logger.error("Bad Request: Missing required parameters.");
      return res.status(400).json({ error: "Bad Request: Missing required parameters 'page' or 'platform'." });
    }

    logger.info(`GET request for template details of page: ${page}, platform: ${platform}`);
    const response = await templateBusiness.getParticularTemplate(page, platform);

    return res.status(response.status).json({ data: response });
  } catch (error) {
    logger.error("Error in getParticularTemplate Controller:", error.message);
    next(error);
  }
};


module.exports = {
  updateAndMapWidget,
  createTemplate,
  getParticularTemplate
}