const logger = require('../utils/logger'); 
const widgetBusiness = require('./business');


const getAllWidget = async (req, res, next) => {
  try {
    const { page } = req.params;
    
    // Log the page requested
    logger.info(`Fetching widgets for page: ${page}`);
    
    if (!page) {
      return res.status(400).json({ error: 'Page parameter is missing' });
    }

    const response = await widgetBusiness.getAllWidget(page);

    return res.status(response.status).json({ data: response.data });
  } catch (error) {
    logger.error(`Error in controller: ${error.message}`);
    return res.status(500).json({ error: 'Internal server error' });
  }
};



const createWidget = async (req, res, next) => {
  try {
    logger.info('createWidget API called'); // Log the API call

    // Validate request body (basic validation)
    if (!req.body || Object.keys(req.body).length === 0) {
      logger.error('Bad Request: No data provided'); // Log bad request
      return res.status(400).json({ message: 'Bad Request: No data provided' });
    }

    const response = await widgetBusiness.createWidget(req.body);

    return res.status(response.status).json({ data: response });
  } catch (error) {
    logger.error(`Error in createWidget controller: ${error.message}`); // Log error
    return res.status(500).json({ message: 'Internal Server Error', error: error.message });
  }
};




module.exports = {
  getAllWidget,
  createWidget,
};